@@ -20,20 +20,34 @@
 #define GTD_TASK_LIST_H
 
 #include <glib-object.h>
+#include <gtk/gtk.h>
 
 #include "gtd-object.h"
-
-#include <libecal/libecal.h>
-#include <gtk/gtk.h>
+#include "gtd-types.h"
 
 G_BEGIN_DECLS
 
 #define GTD_TYPE_TASK_LIST (gtd_task_list_get_type())
 
-G_DECLARE_FINAL_TYPE (GtdTaskList, gtd_task_list, GTD, TASK_LIST, GtdObject)
+G_DECLARE_DERIVABLE_TYPE (GtdTaskList, gtd_task_list, GTD, TASK_LIST, GtdObject)
 
-GtdTaskList*            gtd_task_list_new                       (ESource                *source,
-                                                                 const gchar            *origin);
+struct _GtdTaskListClass
+{
+  GtdObjectClass        parent;
+
+  void                  (*task_added)                           (GtdTaskList            *list,
+                                                                 GtdTask                *task);
+
+  void                  (*task_updated)                         (GtdTaskList            *list,
+                                                                 GtdTask                *task);
+
+  void                  (*task_removed)                         (GtdTaskList            *list,
+                                                                 GtdTask                *task);
+
+  gpointer              padding[10];
+};
+
+GtdTaskList*            gtd_task_list_new                       (GtdProvider            *provider);
 
 GdkRGBA*                gtd_task_list_get_color                 (GtdTaskList            *list);
 
@@ -42,11 +56,16 @@ void                    gtd_task_list_set_color                 (GtdTaskList
 
 gboolean                gtd_task_list_is_removable              (GtdTaskList            *list);
 
+void                    gtd_task_list_set_is_removable          (GtdTaskList            *list,
+                                                                 gboolean                is_removable);
+
 const gchar*            gtd_task_list_get_name                  (GtdTaskList            *list);
 
 void                    gtd_task_list_set_name                  (GtdTaskList            *list,
                                                                  const gchar            *name);
 
+GtdProvider*            gtd_task_list_get_provider              (GtdTaskList            *list);
+
 GList*                  gtd_task_list_get_tasks                 (GtdTaskList            *list);
 
 void                    gtd_task_list_save_task                 (GtdTaskList            *list,
@@ -58,10 +77,6 @@ void                    gtd_task_list_remove_task               (GtdTaskList
 gboolean                gtd_task_list_contains                  (GtdTaskList            *list,
                                                                  GtdTask                *task);
 
-ESource*                gtd_task_list_get_source                (GtdTaskList            *list);
-
-const gchar*            gtd_task_list_get_origin                (GtdTaskList            *list);
-
 G_END_DECLS
 
 #endif /* GTD_TASK_LIST_H */
