@@ -39,6 +39,7 @@ enum
   PROP_COMPLETE,
   PROP_COMPONENT,
   PROP_DESCRIPTION,
+  PROP_CREATION_DATE,
   PROP_DUE_DATE,
   PROP_LIST,
   PROP_PRIORITY,
@@ -49,24 +50,17 @@ enum
 static GDateTime*
 gtd_task__convert_icaltime (const icaltimetype *date)
 {
-  GTimeZone *tz;
   GDateTime *dt;
-  gboolean is_date;
 
   if (!date)
     return NULL;
 
-  is_date = date->is_date ? TRUE : FALSE;
-
-  tz = g_time_zone_new_utc ();
-
-  dt = g_date_time_new (tz,
-                        date->year,
-                        date->month,
-                        date->day,
-                        is_date ? date->hour : 0,
-                        is_date ? date->minute : 0,
-                        is_date ? date->second : 0.0);
+  dt = g_date_time_new_utc (date->year,
+                            date->month,
+                            date->day,
+                            date->is_date ? 0 : date->hour,
+                            date->is_date ? 0 : date->minute,
+                            date->is_date ? 0 : date->second);
 
   return dt;
 }
@@ -140,6 +134,10 @@ gtd_task_get_property (GObject    *object,
       g_value_set_object (value, priv->component);
       break;
 
+    case PROP_CREATION_DATE:
+      g_value_set_boxed (value, gtd_task_get_creation_date (self));
+      break;
+
     case PROP_DESCRIPTION:
       g_value_set_string (value, gtd_task_get_description (self));
       break;
@@ -262,6 +260,20 @@ gtd_task_class_init (GtdTaskClass *klass)
                               E_TYPE_CAL_COMPONENT,
                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
+  /**
+   * GtdTask::creation-date:
+   *
+   * The @GDateTime that represents the time in which the task was created.
+   */
+  g_object_class_install_property (
+        object_class,
+        PROP_CREATION_DATE,
+        g_param_spec_boxed ("creation-date",
+                            "Creation date of the task",
+                            "The day the task was created.",
+                            G_TYPE_DATE_TIME,
+                            G_PARAM_READABLE));
+
   /**
    * GtdTask::description:
    *
@@ -438,7 +450,7 @@ gtd_task_set_complete (GtdTask  *task,
 
       if (complete)
         {
-          GDateTime *now = g_date_time_new_now_local ();
+          GDateTime *now = g_date_time_new_now_utc ();
 
           percent = 100;
           status = ICAL_STATUS_COMPLETED;
@@ -481,6 +493,40 @@ gtd_task_set_complete (GtdTask  *task,
     }
 }
 
+/**
+ * gtd_task_get_creation_date:
+ * @task: a #GtdTask
+ *
+ * Returns the #GDateTime that represents the task's creation date.
+ * The value is referenced for thread safety. Returns %NULL if
+ * no date is set.
+ *
+ * Returns: (transfer full): the internal #GDateTime referenced
+ * for thread safety, or %NULL. Unreference it after use.
+ */
+GDateTime*
+gtd_task_get_creation_date (GtdTask *task)
+{
+  GtdTaskPrivate *priv;
+  icaltimetype *idt;
+  GDateTime *dt;
+
+  g_return_val_if_fail (GTD_IS_TASK (task), NULL);
+  priv = gtd_task_get_instance_private (task);
+
+  idt = NULL;
+  dt = NULL;
+
+  e_cal_component_get_created (priv->component, &idt);
+
+  if (idt)
+    dt = gtd_task__convert_icaltime (idt);
+
+  g_clear_pointer (&idt, e_cal_component_free_icaltimetype);
+
+  return dt;
+}
+
 /**
  * gtd_task_get_description:
  * @task: a #GtdTask
@@ -960,6 +1006,27 @@ gtd_task_compare (GtdTask *t1,
   if (dt2)
     g_date_time_unref (dt2);
 
+  if (retval != 0)
+    return retval;
+
+  /*
+   * Fourth, compare by ::creation-date.
+   */
+  dt1 = gtd_task_get_creation_date (t1);
+  dt2 = gtd_task_get_creation_date (t2);
+
+  if (!dt1 && !dt2)
+    retval =  0;
+  else if (!dt1)
+    retval =  1;
+  else if (!dt2)
+    retval = -1;
+  else
+    retval = g_date_time_compare (dt1, dt2);
+
+  g_clear_pointer (&dt1, g_date_time_unref);
+  g_clear_pointer (&dt2, g_date_time_unref);
+
   if (retval != 0)
     return retval;
 
