@@ -20,7 +20,6 @@
 #include "interfaces/gtd-provider.h"
 #include "interfaces/gtd-panel.h"
 #include "views/gtd-list-selector-panel.h"
-#include "plugin/gtd-plugin-manager.h"
 #include "gtd-application.h"
 #include "gtd-enum-types.h"
 #include "gtd-task-list-view.h"
@@ -28,6 +27,7 @@
 #include "gtd-manager-protected.h"
 #include "gtd-notification.h"
 #include "gtd-notification-widget.h"
+#include "gtd-plugin-manager.h"
 #include "gtd-provider-dialog.h"
 #include "gtd-task.h"
 #include "gtd-task-list.h"
